@@ -1,4 +1,4 @@
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 library(knitr)
 opts_chunk$set(
   fig.align  = "center",
@@ -6,8 +6,7 @@ opts_chunk$set(
   fig.height = 4,
   crop       = TRUE)
 
-## ----message=FALSE, warning=FALSE----------------------------------------
-library(magrittr)
+## ----message=FALSE, warning=FALSE---------------------------------------------
 library(tidyr)
 library(purrr)
 library(dplyr)
@@ -15,14 +14,14 @@ library(coalitions)
 library(ggplot2)
 theme_set(theme_bw())
 
-## ------------------------------------------------------------------------
-temp <- scrape_wahlrecht() %>% slice(1) %>% collapse_parties() %>% unnest()
-temp %<>%
+## -----------------------------------------------------------------------------
+temp <- scrape_wahlrecht() %>% slice(1) %>% collapse_parties() %>% unnest("survey")
+temp <- temp %>%
 	mutate(
 		respondents = 1000L,
 		percent  = c(36, 28, 7, 6, 9, 9, 5),
 		votes    = respondents * percent/100) %>%
-	nest(party:votes, .key=survey)
+	nest(survey = party:votes)
 
 set.seed(29072017)
 draws <- map(temp$survey, draw_from_posterior, nsim=1e4, correction=0.01) %>%
@@ -31,7 +30,7 @@ draws <- map(temp$survey, draw_from_posterior, nsim=1e4, correction=0.01) %>%
 		group_by(party) %>%
 		mutate(sim = row_number()) %>% ungroup()
 
-## ---- fig.width=6, fig.height=6------------------------------------------
+## ---- fig.width=6, fig.height=6-----------------------------------------------
 ggplot(draws_long, aes(x=party, y=percent)) +
 	geom_boxplot() +
 	geom_hline(yintercept = 0.05, lty=2, col=2)
